@@ -1,9 +1,8 @@
 # return a vector of generalized horizon names, based on:
 # a vector of new names
 # a vector of patterns
-generalize.hz <- function(x, new, pat) {
-	# code for non-matching horizons
-	non.matching.code <- 'not-used'
+# code for any non-matching hz designations
+generalize.hz <- function(x, new, pat, non.matching.code='not-used') {
 	
 	# init vector of 'other', same length as original horizon name vector
 	g <- rep(non.matching.code, times=length(x))
