@@ -325,12 +325,11 @@ setReplaceMethod("diagnostic_hz", "SoilProfileCollection",
   
   # test to make sure that at least one of the IDS in candidate data are present within SPC
   if(all( ! unique(value[[idn]]) %in% pIDs) )
-  	stop('candidate diagnostic horizon data have no matching IDs in target object!', call.=FALSE)
+  	warning('candidate diagnostic horizon data have NO matching IDs in target SoilProfileCollection object!', call. = FALSE)
   
   # warn user if some of the IDs in the candidate data are missing
   if(any( ! unique(value[[idn]]) %in% pIDs) ) {
-  	warning('some records in candidate diagnostic horizon data have no matching IDs in target object', call.=FALSE)
-    # print(value[value$peiid == unique(value[[idn]])[which(! unique(value[[idn]]) %in% pIDs)], ])
+    warning('some records in candidate diagnostic horizon data have no matching IDs in target SoilProfileCollection object')
   }
   
   # if data are already present, warn the user
